==> nas_1.2p4-1.tar.gz: nas-1.2p4/lib/audio/CrFlow.c <==
/*
 * Copyright 1993 Network Computing Devices, Inc.
 * 
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name Network Computing Devices, Inc. not be
 * used in advertising or publicity pertaining to distribution of this
 * software without specific, written prior permission.
 * 
 * THIS SOFTWARE IS PROVIDED 'AS-IS'.  NETWORK COMPUTING DEVICES, INC.,
 * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT
 * LIMITATION ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NONINFRINGEMENT.  IN NO EVENT SHALL NETWORK
 * COMPUTING DEVICES, INC., BE LIABLE FOR ANY DAMAGES WHATSOEVER, INCLUDING
 * SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOSS OF USE, DATA,
 * OR PROFITS, EVEN IF ADVISED OF THE POSSIBILITY THEREOF, AND REGARDLESS OF
 * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * $NCDId: @(#)CrFlow.c,v 1.4 1993/01/26 05:13:39 greg Exp $
 */

#include "Alibint.h"

AuFlowID
AuCreateFlow(aud, ret_status)
AuServer       *aud;
AuStatus       *ret_status;
{
    register auResourceReq *req;
    AuFlowID        flow = AuAllocID(aud);

    if (ret_status)
	*ret_status = AuSuccess;

    _AuLockServer(aud);
    _AuGetResReq(CreateFlow, flow, req, aud);

    if (!_AuIfRoundTrip(aud, ret_status))
	flow = AuNone;

    _AuUnlockServer(aud);
    _AuSyncHandle(aud);

    return flow;
}

==> nas_1.8.orig.tar.gz: nas-1.8/lib/audio/CrFlow.c <==
/*
 * Copyright 1993 Network Computing Devices, Inc.
 * 
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name Network Computing Devices, Inc. not be
 * used in advertising or publicity pertaining to distribution of this
 * software without specific, written prior permission.
 * 
 * THIS SOFTWARE IS PROVIDED 'AS-IS'.  NETWORK COMPUTING DEVICES, INC.,
 * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT
 * LIMITATION ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NONINFRINGEMENT.  IN NO EVENT SHALL NETWORK
 * COMPUTING DEVICES, INC., BE LIABLE FOR ANY DAMAGES WHATSOEVER, INCLUDING
 * SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOSS OF USE, DATA,
 * OR PROFITS, EVEN IF ADVISED OF THE POSSIBILITY THEREOF, AND REGARDLESS OF
 * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * $NCDId: @(#)CrFlow.c,v 1.4 1993/01/26 05:13:39 greg Exp $
 */

#include "Alibint.h"

AuFlowID
AuCreateFlow(
             AuServer *aud,
             AuStatus *ret_status
             )
{
    register auResourceReq *req;
    AuFlowID        flow = AuAllocID(aud);

    if (ret_status)
	*ret_status = AuSuccess;

    _AuLockServer();
    _AuGetResReq(CreateFlow, flow, req, aud);

    if (!_AuIfRoundTrip(aud, ret_status))
	flow = AuNone;

    _AuUnlockServer();
    _AuSyncHandle(aud);

    return flow;
}
